@@ -12,6 +12,7 @@ use crate::{
 use chrono::NaiveDate;
 use ego_tree::iter::Edge;
 use itertools::Itertools;
+use logos::Span;
 use scraper::{node::Element, ElementRef, Node};
 use semver::Version;
 use sentence::{Pattern, SentenceRef, Sentences};
@@ -54,6 +55,12 @@ pub enum ParseError {
         #[source]
         ParseBoolError,
     ),
+    #[error("Lexer error: {lexeme:?} ({span:?}) in {input:?}")]
+    Lexer {
+        input: String,
+        lexeme: String,
+        span: Span,
+    },
 }
 
 pub fn parse(raw: Extracted) -> Result<Parsed> {
@@ -189,6 +196,8 @@ pub enum Type {
     },
     String {
         default: Option<String>,
+        min_len: Option<u64>,
+        max_len: Option<u64>,
         one_of: Vec<String>,
     },
     Bool {
@@ -223,6 +232,8 @@ impl Type {
             },
             "String" => Self::String {
                 default: None,
+                min_len: None,
+                max_len: None,
                 one_of: vec![],
             },
             "Boolean" => Self::Bool { default: None },
@@ -302,10 +313,16 @@ impl Type {
                     .map(str::parse)
                     .transpose()?,
             },
-            Type::String { .. } if default.is_some() || one_of.is_some() => Type::String {
-                default,
-                one_of: one_of.unwrap_or_default(),
-            },
+            Type::String { .. }
+                if default.is_some() || min.is_some() || max.is_some() || one_of.is_some() =>
+            {
+                Type::String {
+                    default,
+                    min_len: min.as_deref().map(str::parse).transpose()?,
+                    max_len: max.as_deref().map(str::parse).transpose()?,
+                    one_of: one_of.unwrap_or_default(),
+                }
+            }
             x => x,
         };
 
@@ -553,6 +570,8 @@ mod tests {
                 },
                 Type::String {
                     default: None,
+                    min_len: None,
+                    max_len: None,
                     one_of: vec![]
                 }
             ])
